@@ -49,7 +49,7 @@ impl<'src, D> Recipe<'src, D> {
 
   pub(crate) fn max_arguments(&self) -> usize {
     if self.parameters.iter().any(|p| p.kind.is_variadic()) {
-      usize::max_value() - 1
+      usize::MAX - 1
     } else {
       self.parameters.len()
     }
@@ -182,7 +182,7 @@ impl<'src, D> Recipe<'src, D> {
         || !((quiet_command ^ self.quiet) || config.verbosity.quiet())
       {
         let color = if config.highlight {
-          config.color.command()
+          config.color.command(config.command_color)
         } else {
           config.color
         };
