@@ -99,7 +99,7 @@ impl Subcommand {
       let starting_path = match &config.search_config {
         SearchConfig::FromInvocationDirectory => config.invocation_directory.clone(),
         SearchConfig::FromSearchDirectory { search_directory } => {
-          std::env::current_dir().unwrap().join(search_directory)
+          env::current_dir().unwrap().join(search_directory)
         }
         _ => unreachable!(),
       };
